==> nuiton-utils-1.1.0-sources.jar: org/nuiton/util/VersionNumberConverter.java <==
/* 
* *##% Nuiton utilities library
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%* */
package org.nuiton.util;

import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.beanutils.Converter;
import static org.apache.commons.logging.LogFactory.getLog;
import static org.nuiton.i18n.I18n._;

/**
 * classe pour convertir une chaine en un objet VersionNumber.
 *
 * @author chemit
 * @see VersionNumber
 * @deprecated since 1.6.0, use the {@link VersionConverter} class instead)
 */
@Deprecated
public class VersionNumberConverter implements Converter {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static org.apache.commons.logging.Log log = getLog(VersionNumberConverter.class);

    public Object convert(Class aClass, Object value) {
        if (value == null) {
            throw new ConversionException(_("lutinutil.error.convertor.noValue", this));
        }
        if (isEnabled(aClass)) {
            Object result;
            if (isEnabled(value.getClass())) {
                result = value;
                return result;
            }
            if (value instanceof String) {
                result = valueOf((String) value);
                return result;
            }
        }
        throw new ConversionException(_("lutinutil.error.no.convertor", aClass.getName(), value));
    }

    public VersionNumberConverter() {
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
    }

    protected VersionNumber valueOf(String value) {
        try {
            VersionNumber result;
            String[] str = value.split("\\.");
            if (str.length == 0) {
                return new VersionNumber();
            }
            int[] numbers = new int[str.length];
            for (int i = 0; i < str.length; i++) {
                String number = str[i];
                numbers[i] = Integer.valueOf(number);
            }
            result = new VersionNumber(numbers);
            return result;
        } catch (IllegalArgumentException e) {
            throw new ConversionException(_("lutinutil.error.url.convertor", value, this, e.getMessage()));
        }
    }

    protected boolean isEnabled(Class aClass) {
        return aClass == VersionNumber.class;
    }

}

==> nuiton-utils-1.1.4-sources.jar: org/nuiton/util/VersionNumberConverter.java <==
/* 
* *##% Nuiton utilities library
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%* */
package org.nuiton.util;

import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.beanutils.Converter;
import static org.apache.commons.logging.LogFactory.getLog;
import static org.nuiton.i18n.I18n._;

/**
 * classe pour convertir une chaine en un objet VersionNumber.
 *
 * @author chemit
 * @see VersionNumber
 * @deprecated since 1.6.0, use the {@link VersionConverter} class instead)
 */
@Deprecated
public class VersionNumberConverter implements Converter {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static org.apache.commons.logging.Log log = getLog(VersionNumberConverter.class);

    public Object convert(Class aClass, Object value) {
        if (value == null) {
            throw new ConversionException(_("nuitonutil.error.convertor.noValue", this));
        }
        if (isEnabled(aClass)) {
            Object result;
            if (isEnabled(value.getClass())) {
                result = value;
                return result;
            }
            if (value instanceof String) {
                result = valueOf((String) value);
                return result;
            }
        }
        throw new ConversionException(_("nuitonutil.error.no.convertor", aClass.getName(), value));
    }

    public VersionNumberConverter() {
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
    }

    protected VersionNumber valueOf(String value) {
        try {
            VersionNumber result;
            String[] str = value.split("\\.");
            if (str.length == 0) {
                return new VersionNumber();
            }
            int[] numbers = new int[str.length];
            for (int i = 0; i < str.length; i++) {
                String number = str[i];
                numbers[i] = Integer.valueOf(number);
            }
            result = new VersionNumber(numbers);
            return result;
        } catch (IllegalArgumentException e) {
            throw new ConversionException(_("nuitonutil.error.url.convertor", value, this, e.getMessage()));
        }
    }

    protected boolean isEnabled(Class aClass) {
        return aClass == VersionNumber.class;
    }

}
